import * as vite from 'vite';
import * as unplugin_combine from 'unplugin-combine';
import { Options as Options$1 } from '@vue-macros/define-model';
import { Options as Options$2 } from 'unplugin-vue-define-options';
import { Options as Options$3 } from '@vue-macros/define-render';
import { Options as Options$4 } from '@vue-macros/hoist-static';
import { Options as Options$5 } from '@vue-macros/setup-component';
import { Options as Options$6 } from '@vue-macros/setup-sfc';

interface FeatureOptionsMap {
    defineModel: Options$1;
    defineOptions: Options$2;
    defineRender: Options$3;
    hoistStatic: Options$4;
    setupComponent: Options$5;
    setupSFC: Options$6;
}
declare type FeatureName = keyof FeatureOptionsMap;
declare type FeatureOptions = FeatureOptionsMap[FeatureName];
interface OptionsCommon {
    root?: string;
    version?: 2 | 3;
    plugins?: {
        vue?: any;
        vueJsx?: any;
    };
}
declare type OptionalSubOptions<T> = boolean | Omit<T, keyof OptionsCommon> | undefined;
declare type Options = OptionsCommon & {
    [K in FeatureName]?: OptionalSubOptions<FeatureOptionsMap[K]>;
};
declare type OptionsResolved = Required<OptionsCommon> & {
    [K in FeatureName]: false | FeatureOptionsMap[K];
};
declare const _default: {
    readonly rollup: (options?: Options | undefined) => unplugin_combine.RollupPlugin;
    readonly vite: (options?: Options | undefined) => vite.Plugin[];
    readonly esbuild: (options?: Options | undefined) => unplugin_combine.EsbuildPlugin;
    readonly webpack: (options?: Options | undefined) => any;
};

export { FeatureName, FeatureOptions, FeatureOptionsMap, Options, OptionsCommon, OptionsResolved, _default as default };
